@@ -1,5 +1,3 @@
-#![feature(generic_associated_types)]
-// This is necessary for now, hopefully we can go back to stable around October
 #![warn(missing_docs, unused_imports)]
 
 //! _This is a part of **scicrypt**. For more information, head to the
@@ -9,6 +7,8 @@
 //! Paillier, ElGamal and RSA. We also implement several threshold versions of the cryptosystems,
 //! where multiple keys must be used to successfully decrypt a ciphertext.
 
+mod constants;
+
 /// Partially homomorphic cryptosystems with one key.
 pub mod cryptosystems;
 
